@@ -91,6 +91,8 @@ void dumpdata(const unsigned int ticks, const char file[], const unsigned int li
 		float db = 100.0 * (float) results->db / ticks;
 		float cr = 100.0 * (float) results->cr / ticks;
 		float cb = 100.0 * (float) results->cb / ticks;
+		float vram = 100.0 * (float) results->vram / vramsize;
+		float vrammb = results->vram / 1024.0f / 1024.0f;
 
 		fprintf(f, "gpu %.2f%%, ", gui);
 		fprintf(f, "ee %.2f%%, ", ee);
@@ -113,7 +115,12 @@ void dumpdata(const unsigned int ticks, const char file[], const unsigned int li
 		fprintf(f, "sc %.2f%%, ", sc);
 		fprintf(f, "pa %.2f%%, ", pa);
 		fprintf(f, "db %.2f%%, ", db);
-		fprintf(f, "cb %.2f%%\n", cb);
+		fprintf(f, "cb %.2f%%", cb);
+
+		if (bits.vram)
+			fprintf(f, ", vram %.2f%% %.2fmb\n", vram, vrammb);
+		else
+			fprintf(f, "\n");
 
 		fflush(f);
 
