@@ -52,6 +52,10 @@ const char * const family_str[] = {
 	str(HAINAN),
 	str(BONAIRE),
 	str(KABINI),
+	str(MULLINS),
 	str(KAVERI),
 	str(HAWAII),
+	str(TOPAZ),
+	str(TONGA),
+	str(CARRIZO),
 };
